Empirical transition counts for bivariate dyadic sequences
Source:R/apim-bivariate.R
countEmpBivariate.RdComputes empirical transition counts for bivariate categorical dyadic
sequences with two variables. This function currently supports
states = 2 only.
Value
An integer matrix with class
c("dyadic_counts", "matrix", "array") with 16 rows and 2 columns
when states = 2. It remains usable as an ordinary matrix.
Details
The bivariate counter currently supports states = 2 only.
Rows represent the previous dyadic states of variable 1 and variable 2.
Writing \(K\) for the number of states, the row index at time \(t\) is
$$r_t = 1 + K^2 [K(FM_{V1,t} - 1) + (SM_{V1,t} - 1)] + K(FM_{V2,t} - 1) + (SM_{V2,t} - 1)$$
Columns correspond to
the state of the first member on variable 1 at the next time point,
\(FM_{V1,t+1}\).