Empirical transition counts for bivariate dyadic sequences
Source:R/apim-bivariate.R
countEmpBivariate.RdComputes empirical transition counts for bivariate categorical dyadic
sequences with two variables. This function currently supports
states = 2 only.
Value
An integer matrix with class
c("dyadic_counts", "matrix", "array") with 16 rows and 2 columns
when states = 2. It remains usable as an ordinary matrix.
Details
The bivariate counter currently supports states = 2 only.
Rows represent the previous dyadic states of variable 1 and variable 2.
The implementation uses the row mapping
states^2 * (states * (FM_V1,t - 1) + (SM_V1,t - 1)) +
states * (FM_V2,t - 1) + (SM_V2,t - 1) + 1. Columns correspond to
the state of the first member on variable 1 at the next time point,
\(FM_{V1,t+1}\).